@@ -8,13 +8,13 @@
 #
 package MooX::Options;
 
-# ABSTRACT: add option keywords to your object (Mo/Moo/Moose)
+# ABSTRACT: create a command line tools with your Object (Mo / Moo / Moose)
 
 use strict;
 use warnings;
 use Carp;
 
-our $VERSION = '3.92';    # VERSION
+our $VERSION = '3.93';    # VERSION
 my @OPTIONS_ATTRIBUTES
     = qw/format short repeatable negativable autosplit doc order json/;
 
@@ -190,13 +190,13 @@ __END__
 
 =head1 NAME
 
-MooX::Options - add option keywords to your object (Mo/Moo/Moose)
+MooX::Options - create a command line tools with your Object (Mo / Moo / Moose)
 
 =head1 VERSION
 
-version 3.92
+version 3.93
 
-=head1 MooX::Options
+=head1 DESCRIPTION
 
 Use L<Getopt::Long::Descritive> to provide command line option for your Mo/Moo/Moose Object.
 
@@ -335,6 +335,31 @@ You can also use it over a Role.
     my $t = t->new_with_options(); #parse @ARGV
     my $o = t->new_with_options(test => 'override'); #parse ARGV and override any value with the params here
 
+If you use Mo, you have a little bit more work to do. Because Mo lack of "with" and "around".
+
+    {
+        package tRole;
+        use Moo::Role;
+        use Mo;
+        use MooX::Options;
+
+        option 'test' => (is => 'ro');
+        1;
+    }
+    {
+
+        package t;
+        use Mo;
+        use Role::Tiny::With;
+        with 'tRole';
+
+        1;
+    }
+    my $t = t->new_with_options(); #parse @ARGV
+    my $o = t->new_with_options(test => 'override'); #parse ARGV and override any value with the params here
+
+It's a bit tricky but, hey, you are using Mo !
+
 =head2 Keyword 'options_usage'
 
 It display the usage message and return the exit code
@@ -556,10 +581,6 @@ For example, --start-date or --start_date will fill the option 'start_date'.
 
 If you are using Mouse, I'm sorry to say than the rewrite of this module has make it just incompatible. Mouse is not design to by compatible with anything else than Mouse itself. I could just suggest to use Moo instead, which is a great and compatible replacement.
 
-=head1 no more Mo support
-
-Mo start using Mouse as a backend, so no more support !
-
 =head1 More examples
 
 L<http://perltalks.celogeek.com/slides/2012/08/moox-options-slide3d.html>
